@@ -5,6 +5,7 @@ from typing import List, Optional, Sequence, Set
 
 from pydantic import BaseModel, validate_arguments
 
+from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
 from ..types import AccountType, Currency
@@ -18,7 +19,7 @@ class BalanceRecord(BaseModel):
     ts: int
     currency: Optional[Currency]
     labels: Set[str]
-    account_number: str
+    account_id: str
     account_type: Optional[AccountType]
 
 
@@ -34,7 +35,7 @@ class BalancesMeta(BaseModel):
 
 
 class BalancesAccount(BaseModel):
-    account_number: str
+    account_id: str
     account_type: Optional[AccountType]
     records: List[BalanceRecord]
 
@@ -77,6 +78,7 @@ class BaseBalancesResource(ABC):
         return BalancesResponse(**response.json())
 
     @validate_arguments
+    @cache
     async def _get(
         self,
         user_uuid: str,
